OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Mensaje incrustado %s",
    "Important mail" : "Correo importante",
    "No message found yet" : "Aún no se han encontrado mensajes",
    "Set up an account" : "Configurar una cuenta",
    "Unread mail" : "Correo sin leer",
    "Important" : "Importante",
    "Work" : "Trabajo",
    "Personal" : "Personal",
    "To Do" : "Por hacer",
    "Later" : "Después",
    "Mail" : "Correo",
    "Mails" : "Correos",
    "💌 A mail app for Nextcloud" : "Una app de correo para Nextcloud",
    "Drafts are saved in:" : "Los borradores se guardan en:",
    "Sent messages are saved in:" : "Los mensajes enviados se guardan en:",
    "Deleted messages are moved in:" : "Los mensajes eliminados son movidos a:",
    "Connecting" : "Conectando",
    "Save" : "Guardar",
    "Connect" : "Conectar",
    "Password required" : "Se requiere contraseña",
    "Auto" : "Auto",
    "Name" : "Nombre",
    "Mail address" : "Dirección de correo",
    "name@example.org" : "nombre@ejemplo.org",
    "Please enter an email of the format name@example.com" : "Por favor ingresa un correo en el formato nombre@ejemplo.com",
    "Password" : "Contraseña",
    "Manual" : "Manual",
    "IMAP Settings" : "Configuración IMAP",
    "IMAP Host" : "Servidor IMAP",
    "IMAP Security" : "Seguridad IMAP",
    "None" : "Ninguno",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Puerto IMAP",
    "IMAP User" : "Usuario IMAP",
    "IMAP Password" : "Contraseña IMAP",
    "SMTP Settings" : "Configuración SMTP",
    "SMTP Host" : "Servior SMTP",
    "SMTP Security" : "Seguridad SMTP",
    "SMTP Port" : "Puerto SMTP",
    "SMTP User" : "Usuario SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Account settings" : "Ajustes de la cuenta",
    "Aliases" : "Aliases",
    "Signature" : "Firma",
    "A signature is added to the text of new messages and replies." : "Se ha añadido una firma al texto de los nuevos mensajes y respuestas.",
    "Writing mode" : "Modo de escritura",
    "Preferred writing mode for new messages and replies." : "Modo preferido de escritura para nuevos mensajes y respuestas.",
    "Default folders" : "Carpetas predeterminadas",
    "Mail server" : "Servidor de correo",
    "Update alias" : "Actualizar alias",
    "Show update alias form" : "Mostrar formulario de actualización de alias",
    "Delete alias" : "Borrar alias",
    "Go back" : "Regresar",
    "Change name" : "Cambiar nombre",
    "Email address" : "Dirección de correo electrónico",
    "Add alias" : "Añadir alias",
    "Create alias" : "Crear alias",
    "Cancel" : "Cancelar",
    "Put my text to the bottom of a reply instead of on top of it." : "Ponga mi texto al final de la respuesta en vez de encima de ella.",
    "Could not update preference" : "No se pudo actualizar la preferencia",
    "Add mail account" : "Agregar cuenta de correo",
    "General" : "General",
    "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
    "Register as application for mail links" : "Usar aplicación para abrir enlaces de correo",
    "Register" : "Registrar",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permitir a la app recolectar datos sobre sus interacciones. Basándose en estos datos, la app se adaptará mejor a sus preferencias. Estos datos sólo se almacenan localmente.",
    "Trusted senders" : "Remitentes de confianza",
    "About" : "Acerca",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Compose new message" : "Escribir mensaje nuevo",
    "Newer message" : "Mensaje más nuevo",
    "Older message" : "Mensaje más antiguo",
    "Toggle star" : "Alternar favoritos",
    "Toggle unread" : "Alternar no leídos",
    "Archive" : "Archivar",
    "Delete" : "Borrar",
    "Search" : "Buscar",
    "Send" : "Enviar",
    "Refresh" : "Actualizar",
    "Message {id} could not be found" : "No se ha podido encontrar el mensaje {id}",
    "From" : "De",
    "Select account" : "Selecciona la cuenta",
    "To" : "Para",
    "Contact or email address …" : "Contacto o dirección de correo electrónico ...",
    "Cc" : "Cc",
    "Bcc" : "Cco",
    "Subject" : "Asunto",
    "Subject …" : "Asunto…",
    "This message came from a noreply address so your reply will probably not be read." : "Este correo viene de una dirección no responder , por lo que probablemente su respuesta no será leída.",
    "The following recipients do not have a PGP key: {recipients}." : "Los siguientes destinatarios no tienen una clave PGP: {recipients}",
    "Write message …" : "Escribir mensaje …",
    "Saving draft …" : "Guardando borrador…",
    "Draft saved" : "Borrador guardado",
    "Discard & close draft" : "Descartar y cerrar borrador",
    "Enable formatting" : "Habilitar formato",
    "Upload attachment" : "Cargar adjunto",
    "Add attachment from Files" : "Agregar adjunto desd Archivos",
    "Request a read receipt" : "Solicitar acuse de lectura",
    "Encrypt message with Mailvelope" : "Cifrar el mensaje con Mailvelope",
    "Choose" : "Seleccionar",
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Los archivos adjuntos exceden el tamaño permitido de {size}. Por favor comparte a través de  un enlace.","Los archivos adjuntos superan el tamaño permitido de {size}. Por favor envía los archivos mediante un enlace.","Los archivos adjuntos superan el tamaño permitido de {size}. Por favor envía los archivos mediante un enlace."],
    "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
    "Choose a file to share as a link" : "Selecciona un archivo para compartir como enlace",
    "Confirm" : "Confirmar",
    "Plain text" : "Texto simple",
    "Rich text" : "Texto enriquecido",
    "No messages in this mailbox" : "No hay mensajes en esta bandeja",
    "No messages" : "No hay mensajes",
    "Draft: " : "Borrador:",
    "Unfavorite" : "Desmarcar como favorito",
    "Favorite" : "Favorito",
    "Read" : "Leer",
    "Edit tags" : "Editar etiquetas",
    "More actions" : "Más acciones",
    "Back" : "Atrás",
    "All day" : "Todo el día",
    "Description" : "Descripción",
    "Create" : "Crear",
    "Select" : "Seleccionar",
    "Comment" : "Comentario",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Remove" : "Eliminar",
    "email" : "correo electrónico",
    "Other" : "Otro",
    "Forward" : "Adelante",
    "Translate" : "Traducir",
    "Unnamed" : "Sin nombre",
    "Choose a folder to store the attachment in" : "Seleccciona la carpeta en la cual almacenar el adjunto",
    "Import into calendar" : "Importar al calendario",
    "Download attachment" : "Descargar adjunto",
    "Save to Files" : "Guardar a Archivos",
    "Save all to Files" : "Guardar todo a Archivos",
    "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
    "Move" : "Mover",
    "Remove account" : "Eliminar cuenta",
    "Quota" : "Cuota",
    "Saving" : "Guardando",
    "Mark all as read" : "Marcar todos como leídos",
    "Rename" : "Renombrar",
    "Clear cache" : "Borrar el caché",
    "New message" : "Mensaje nuevo",
    "Reply" : "Responder",
    "No sent mailbox configured. Please pick one in the account settings." : "No hay configurada una bandeja de enviados. Por favor, elija una en la configuración de la cuenta.",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Está intentando enviar a muchos destinatarios en Para y/o Cc. Considera usar Cco para ocultar las direcciones de los destinatarios.",
    "Error sending your message" : "Error al enviar tu mensaje",
    "Retry" : "Reintentar",
    "Warning sending your message" : "Alerta al enviar su mensaje",
    "Send anyway" : "Enviar de todas formas",
    "Message" : "Mensaje",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Add" : "Agregar",
    "Clear" : "Limpiar",
    "Date" : "Fecha",
    "Tags" : "Etiquetas",
    "Select tags" : "Selecciona las etiquetas",
    "Custom" : "Personalizado",
    "All" : "Todos",
    "Drafts" : "Borradores",
    "Favorites" : "Favoritos",
    "All inboxes" : "Todos los buzones de entrada",
    "Inbox" : "Buzón de entrada",
    "Junk" : "Basura",
    "Sent" : "Enviado",
    "Trash" : "Basura",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n mensaje nuevo \nde {from}","%n mensajes nuevos \nde {from}","%n mensajes nuevos \nde {from}"],
    "Nextcloud Mail" : "Correo Nextcloud",
    "Could not load {tag}{name}{endtag}" : "No fue posible cargar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Se presentó un problema al cargar  {tag}{name}{endtag}",
    "Could not load your message" : "No fue posible cargar tu mensaje",
    "Could not load the desired message" : "No fue posible cargar el mensaje deseado",
    "Could not load the message" : "No fue posible cargar el mensaje",
    "Error loading message" : "Se presentó un error al cargar el mensaje",
    "Forwarding to %s" : "Reenviando a %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Haz click aqui si no eres redireccionado automáticamente dentro de los siguietes segundos. ",
    "Redirect" : "Redireccionar",
    "The link leads to %s" : "La liga lleva a %s",
    "Continue to %s" : "Continuar a %s"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
